@@ -81,12 +81,12 @@ namespace clx {
 			program_ = argv[0];
 			string_type key;
 			bool eoh = false; // end of head parameter
-			for (int i = 1; i < argc; i++) {
+			for (int i = 1; i < argc; ++i) {
 				string_type tmp(argv[i]);
 				if (tmp.at(0) == identifier_) { // make a new entry
 					eoh = true;
 					if (tmp.size() > 2 && tmp.at(1) != identifier_) {
-						for (size_type j = 1; j < tmp.size(); j++) {
+						for (size_type j = 1; j < tmp.size(); ++j) {
 							key = tmp.at(j);
 							this->set_param(key, string_type());
 						}
@@ -125,7 +125,7 @@ namespace clx {
 		
 		bool exist(const string_type& x) {
 			functor f(x);
-			for (size_type i = 0; i < f.size(); i++) {
+			for (size_type i = 0; i < f.size(); ++i) {
 				if (v_.find(f.at(i)) != v_.end()) return true;
 			}
 			return false;
@@ -195,7 +195,7 @@ namespace clx {
 		template <class ValueT>
 		basic_argument& get_param(const string_type& key, ValueT& dest, size_type n) {
 			functor f(key);
-			for (size_type i = 0; i < f.size(); i++) {
+			for (size_type i = 0; i < f.size(); ++i) {
 				if (this->exist(f.at(i)) && n < v_[f.at(i)].size()) {
 					dest = lexical_cast<ValueT>(v_[f.at(i)][n]);
 				}
