@@ -74,7 +74,7 @@ namespace clx {
 		//  escape
 		/* ----------------------------------------------------------------- */
 		template <class CharT, class InputIterator, class OutputIterator>
-		OutputIterator escape(InputIterator first, InputIterator last, OutputIterator result) {
+		inline OutputIterator escape(InputIterator first, InputIterator last, OutputIterator result) {
 			typedef clx::detail::escape_dictionary<CharT> dict_type;
 			typedef CharT char_type;
 			typedef typename dict_type::iterator iterator;
@@ -82,14 +82,10 @@ namespace clx {
 			static dict_type dict;
 			
 			while (first != last) {
-				char_type ch = *first;
-				first++;
+				char_type ch = *first++;
 				iterator pos = dict.find(ch);
 				if (pos != dict.end()) result = std::copy(pos->second.begin(), pos->second.end(), result);
-				else {
-					*result = ch;
-					result++;
-				}
+				else *result++ = ch;
 			}
 			
 			return result;
@@ -99,8 +95,10 @@ namespace clx {
 		//  escape
 		/* ----------------------------------------------------------------- */
 		template <class Ch, class Tr>
-		std::basic_string<Ch, Tr> escape(const std::basic_string<Ch, Tr>& s) {
+		inline std::basic_string<Ch, Tr> escape(const std::basic_string<Ch, Tr>& s) {
 			std::basic_string<Ch, Tr> tmp;
+			if (s.empty()) return tmp;
+			
 			std::insert_iterator<std::basic_string<Ch, Tr> > pos(tmp, tmp.begin());
 			escape<Ch>(s.begin(), s.end(), pos);
 			return tmp;
@@ -110,7 +108,7 @@ namespace clx {
 		//  escape
 		/* ----------------------------------------------------------------- */
 		template <class CharT>
-		std::basic_string<CharT> escape(const CharT* s) {
+		inline std::basic_string<CharT> escape(const CharT* s) {
 			std::basic_string<CharT> tmp(s);
 			return escape(tmp);
 		}
