@@ -66,6 +66,10 @@ namespace clx {
 			socket_type(), host_(), port_(0), ver_(1.1),
 			code_(0), message_(), head_(), body_() {}
 		
+		basic_http(const basic_http& cp) :
+			socket_type(cp), host_(cp.host_), port_(cp.port_), ver_(cp.ver_),
+			code_(cp.code_), message_(cp.message_), head_(cp.head_), body_(cp.body_) {}
+		
 		explicit basic_http(const socket_type& cp) :
 			socket_type(cp), host_(), port_(0), ver_(1.1),
 			code_(0), message_(), head_(), body_() {
@@ -85,7 +89,7 @@ namespace clx {
 			this->start();
 		}
 		
-		virtual ~basic_http() { this->finish(); }
+		virtual ~basic_http() throw() { this->finish(); }
 		
 		basic_http& start() {
 			this->connect(host_, port_);
@@ -103,7 +107,7 @@ namespace clx {
 			return this->start(tmp, port);
 		}
 		
-		void finish() { if (this->is_open()) this->close(); }
+		void finish() { this->close(); }
 		
 		void reset() {
 			code_ = 0;
